minmax_scaler: scale a dataset and return a scaled dataframe, the colmin and...

View source: R/data-scaler.R

minmax_scalerR Documentation

scale a dataset and return a scaled dataframe, the colmin and colmax of each column

Description

scale a dataset and return a scaled dataframe, the colmin and colmax of each column

Usage

minmax_scaler(data)

Arguments

data

A data frame


agnesdeng/misle documentation built on Sept. 22, 2023, 8:48 p.m.